@@ -29,7 +29,7 @@ def run_parser(args=None) -> Optional[Namespace]:
     return parser.parse_args(args, namespace=None)
 
 
-def main() -> int:
+def count_command_line() -> int:
     args = run_parser()
     if args.filename:
         file_path = validate_file(args.filename)
@@ -41,4 +41,4 @@ def main() -> int:
 
 
 if __name__ == '__main__':
-    main()
+    count_command_line()
